@@ -5,14 +5,47 @@
 # This software may be used and distributed according to the terms of the
 # GNU General Public License version 2, incorporated herein by reference.
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from __future__ import absolute_import
 
 import os
 
-from tortoisehg.util import hglib
-from tortoisehg.util.i18n import _
-from tortoisehg.hgqt import qtlib, cmdui, csinfo, visdiff, thgrepo
+from .qtcore import (
+    QAbstractTableModel,
+    QItemSelectionModel,
+    QMimeData,
+    QModelIndex,
+    QPoint,
+    QSettings,
+    QUrl,
+    Qt,
+    pyqtSlot,
+)
+from .qtgui import (
+    QAction,
+    QActionGroup,
+    QComboBox,
+    QDialog,
+    QDialogButtonBox,
+    QHBoxLayout,
+    QKeySequence,
+    QLabel,
+    QMenu,
+    QMessageBox,
+    QToolButton,
+    QTreeView,
+    QVBoxLayout,
+)
+
+from ..util import hglib
+from ..util.i18n import _
+from . import (
+    cmdcore,
+    cmdui,
+    csinfo,
+    qtlib,
+    thgrepo,
+    visdiff,
+)
 
 MARGINS = (8, 0, 0, 0)
 
@@ -20,6 +53,7 @@ class ResolveDialog(QDialog):
     def __init__(self, repoagent, parent=None):
         super(ResolveDialog, self).__init__(parent)
         self._repoagent = repoagent
+        self._cmdsession = cmdcore.nullCmdSession()
         self.setWindowFlags(self.windowFlags()
                             & ~Qt.WindowContextHelpButtonHint
                             | Qt.WindowMaximizeButtonHint)
@@ -128,7 +162,7 @@ class ResolveDialog(QDialog):
         vbox.setContentsMargins(*MARGINS)
         hbox.addLayout(vbox)
         for action in [cmauto, cmmanual, cmlocal, cmother, cmres]:
-            vbox.addWidget(ActionPushButton(action, self))
+            vbox.addWidget(qtlib.ActionPushButton(action, self))
         vbox.addStretch(1)
 
         res = qtlib.LabeledSeparator(_('Resolved conflicts'))
@@ -174,7 +208,7 @@ class ResolveDialog(QDialog):
         vbox.setContentsMargins(*MARGINS)
         hbox.addLayout(vbox)
         for action in [cmedit, cmv3way, cmvp0, cmvp1, cmures]:
-            vbox.addWidget(ActionPushButton(action, self))
+            vbox.addWidget(qtlib.ActionPushButton(action, self))
         vbox.addStretch(1)
 
         hbox = QHBoxLayout()
@@ -199,7 +233,7 @@ class ResolveDialog(QDialog):
         self.bbox = bbox
 
         s = QSettings()
-        self.restoreGeometry(s.value('resolve/geom').toByteArray())
+        self.restoreGeometry(qtlib.readByteArray(s, 'resolve/geom'))
 
         self.refresh()
         self.utree.selectAll()
@@ -233,8 +267,10 @@ class ResolveDialog(QDialog):
             selected = [(r, w) for r, w in selected if r != curroot]
         if cmdlines:
             sess = self._repoagent.runCommandSequence(cmdlines, self)
+            self._cmdsession = sess
             sess.commandFinished.connect(self.refresh)
             sess.outputReceived.connect(self._cmdlog.appendLog)
+            self._updateActions()
 
     def merge(self, tool=False):
         if not tool:
@@ -246,8 +282,7 @@ class ResolveDialog(QDialog):
 
     @pyqtSlot(QAction)
     def _mergeByAction(self, action):
-        tool = str(action.data().toString())
-        self.merge(tool)
+        self.merge(action.data())
 
     def markresolved(self):
         self.runCommand(self.utree, ['resolve', '--mark'])
@@ -345,12 +380,10 @@ class ResolveDialog(QDialog):
 
         model = self.utree.model()
         smodel = self.utree.selectionModel()
-        sflags = QItemSelectionModel.Select | QItemSelectionModel.Columns
+        sflags = QItemSelectionModel.Select | QItemSelectionModel.Rows
         for i, path in enumerate(u):
             if path in paths:
                 smodel.select(model.index(i, 0), sflags)
-                smodel.select(model.index(i, 1), sflags)
-                smodel.select(model.index(i, 2), sflags)
 
         smodel.selectionChanged.connect(self._updateUnresolvedActions)
         self._updateUnresolvedActions()
@@ -368,8 +401,6 @@ class ResolveDialog(QDialog):
         for i, path in enumerate(r):
             if path in paths:
                 smodel.select(model.index(i, 0), sflags)
-                smodel.select(model.index(i, 1), sflags)
-                smodel.select(model.index(i, 2), sflags)
 
         smodel.selectionChanged.connect(self._updateResolvedActions)
         self._updateResolvedActions()
@@ -395,18 +426,24 @@ class ResolveDialog(QDialog):
                 return
         super(ResolveDialog, self).reject()
 
+    def _updateActions(self):
+        self._updateUnresolvedActions()
+        self._updateResolvedActions()
+
     @pyqtSlot()
     def _updateUnresolvedActions(self):
-        enable = self.utree.selectionModel().hasSelection()
+        enable = (self.utree.selectionModel().hasSelection()
+                  and self._cmdsession.isFinished())
         for c in self.umenuitems:
             c.setEnabled(enable)
 
     @pyqtSlot()
     def _updateResolvedActions(self):
-        enable = self.rtree.selectionModel().hasSelection()
+        enable = (self.rtree.selectionModel().hasSelection()
+                  and self._cmdsession.isFinished())
         for c in self.rmenuitems:
             c.setEnabled(enable)
-        merge = len(self.repo.parents()) > 1
+        merge = len(self.repo[None].parents()) > 1
         for c in self.rmmenuitems:
             c.setEnabled(enable and merge)
 
@@ -446,11 +483,11 @@ class PathsModel(QAbstractTableModel):
 
     def data(self, index, role=Qt.DisplayRole):
         if not index.isValid():
-            return QVariant()
+            return None
         if role == Qt.DisplayRole:
             data = self.rows[index.row()][index.column()]
-            return QVariant(hglib.tounicode(data))
-        return QVariant()
+            return hglib.tounicode(data)
+        return None
 
     def flags(self, index):
         flags = super(PathsModel, self).flags(index)
@@ -461,9 +498,9 @@ class PathsModel(QAbstractTableModel):
 
     def headerData(self, col, orientation, role=Qt.DisplayRole):
         if role != Qt.DisplayRole or orientation != Qt.Horizontal:
-            return QVariant()
+            return None
         else:
-            return QVariant(self.headers[col])
+            return self.headers[col]
 
     def getPathForIndex(self, index):
         'return root, wfile for the given row'
@@ -481,27 +518,6 @@ class PathsModel(QAbstractTableModel):
         return data
 
 
-class ActionPushButton(QPushButton):
-    def __init__(self, action, parent=None):
-        super(ActionPushButton, self).__init__(parent)
-        self._defaultAction = action
-        self.addAction(action)
-        self.clicked.connect(action.trigger)
-        self._copyActionProps()
-
-    def actionEvent(self, event):
-        if (event.type() == QEvent.ActionChanged
-            and event.action() is self._defaultAction):
-            self._copyActionProps()
-        super(ActionPushButton, self).actionEvent(event)
-
-    def _copyActionProps(self):
-        action = self._defaultAction
-        self.setEnabled(action.isEnabled())
-        self.setText(action.text())
-        self.setToolTip(action.toolTip())
-
-
 class ToolsCombo(QComboBox):
     def __init__(self, repo, parent):
         QComboBox.__init__(self, parent)
