@@ -7,7 +7,7 @@
 # GNU General Public License version 2, incorporated herein by reference.
 
 shortlicense = '''
-Copyright (C) 2008-2017 Steve Borho <steve@borho.org> and others.
+Copyright (C) 2008-2018 Steve Borho <steve@borho.org> and others.
 This is free software; see the source for copying conditions.  There is NO
 warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 '''
@@ -19,7 +19,7 @@ import sys
 import subprocess
 
 from mercurial import util, fancyopts, cmdutil, extensions, error, scmutil
-from mercurial import pathutil
+from mercurial import pathutil, registrar
 
 from tortoisehg.util.i18n import agettext as _
 from tortoisehg.util import hglib, paths, i18n
@@ -47,7 +47,7 @@ def dispatch(args, u=None):
             pdb.set_trace()
         return _runcatch(u, args)
     except error.ParseError, e:
-        qtapp.earlyExceptionMsgBox(e)
+        qtapp.earlyExceptionMsgBox(hglib.tounicode(str(e)))
     except SystemExit, e:
         return e.code
     except Exception, e:
@@ -243,6 +243,8 @@ def _runcatch(ui, args):
     try:
         # read --config before doing anything else like Mercurial
         hglib.parseconfigopts(ui, args)
+        # register config items specific to TortoiseHg GUI
+        ui.setconfig('extensions', 'tortoisehg.util.configitems', '', 'run')
         try:
             return runcommand(ui, args)
         finally:
@@ -391,7 +393,7 @@ def _runcommand(ui, options, cmd, cmdfunc):
 qtrun = qtapp.QtRunner()
 
 table = {}
-command = hglib.command(table)
+command = registrar.command(table)
 
 # common command options
 
