@@ -6,6 +6,7 @@
 # GNU General Public License version 2 or any later version.
 
 import os
+import re
 import cStringIO
 import ConfigParser
 from mercurial import error, util, config as config_mod
@@ -22,12 +23,17 @@ if _hasiniparse:
         change_comment_syntax(allow_rem=False)
     except (ImportError, TypeError):
         # TODO: yet need to care about iniparse<0.3.2 ??
-        import re
         from iniparse.ini import CommentLine
         # Monkypatch this regex to prevent iniparse from considering
         # 'rem' as a comment
         CommentLine.regex = re.compile(r'^(?P<csep>[%;#])(?P<comment>.*)$')
 
+    # allow :suboption in <name>
+    from iniparse.ini import OptionLine
+    OptionLine.regex = re.compile(r'^(?P<name>[^:=\s[][^=]*)'
+                                  r'(?P<sep>=\s*)'
+                                  r'(?P<value>.*)$')
+
 class _wsortdict(object):
     """Wrapper for config.sortdict to record set/del operations"""
     def __init__(self, dict):
@@ -73,6 +79,8 @@ class _wsortdict(object):
         return len(self._dict)
 
     def update(self, src):
+        if isinstance(src, _wsortdict):
+            src = src._dict
         self._dict.update(src)
         self._logupdate(src)
 
@@ -137,6 +145,11 @@ class _wconfig(object):
             return self._sections[section]
         except KeyError:
             if self._config[section]:
+                # get around COW behavior introduced by hg c41444a39de2, where
+                # an inner dict may be replaced later on preparewrite(). our
+                # wrapper expects non-empty config[section] instance persists.
+                data = self._config._data
+                data[section] = data[section].preparewrite()
                 self._sections[section] = _wsortdict(self._config[section])
                 return self._sections[section]
             else:
